@@ -1,7 +1,5 @@
 import os
-
-__version_trait = (1, 0, 0)
-__version = ".".join(map(str, __version_trait))
+import themata
 
 def get_path():
     """
@@ -9,14 +7,10 @@ def get_path():
     """
     return os.path.abspath(os.path.dirname(os.path.dirname(__file__)))
 
-
-def update_context(app, pagename, templatename, context, doctree):
-    context["water_version"] = __version
-
-
 def setup(app):
     if hasattr(app, "add_html_theme"):
         theme_path = os.path.abspath(os.path.dirname(__file__))
         app.add_html_theme("water", theme_path)
-    app.connect("html-page-context", update_context)
-    return {"version": __version}
\ No newline at end of file
+    app.connect("html-page-context", themata.update_context)
+    app.connect('build-finished', themata.copy_custom_files)
+    return {"version": themata.__version}
\ No newline at end of file
